# fcutils
Utility functions used across a number of projects.
These mainly automate/facilitate handling of files input/output, 
some maths/stats, dealing with videos and improving the aesthetics of plots.
Given that this code is mainly for personal use, don't expect it to be
fully documented or organized, sorry. 

For any issue, bug or feature request please open an issue or a pull request.


# Installation
Install with
```
pip install git+https://github.com/FedeClaudi/fcutils.git
```

Update with:
```
pip install git+https://github.com/FedeClaudi/fcutils.git --upgrade
```
